#!/bin/bash
#
# Pretty dumb script which makes sure our local patches against the
# upstream lineage-16.0 tree are applied in the right sequence.
#
# A minimal description of the individual patches is found in the
# respectice header of the patch file.
#
# Since August 2022, we first pick some asb topics that have been verified
# on other devices, but are becoming slow to be code-reviewed and merged.
# 
##########################
#
#
# repopick some pending ASBs
#
thisdir=`pwd`
cd ~/android/lineage
source build/envsetup.sh
croot
echo "--- 2022-05 ASB ---"
repopick -t P_asb_2022-05     # May 22, problems with other device, not merged
echo "--- 2022-06 ASB ---"
repopick -t P_asb_2022-06     # Verified, but not merged
echo "--- 2022-07 ASB ---"
repopick -t P_asb_2022-07     # Verified, but not merged
echo "--- 2022-08 ASB ---"
repopick -t P_asb_2022-08     # Verified, but not merged
echo "--- 2022-09 ASB ---"
# For the 2022-09 ASB some picks need manual path spec.
# repopick -t P_asb_2022-09   # Fails because of path not found in 338353
repopick 338346 338347 338348 338349 338350 338351 338352
repopick --path /home/puma/android/lineage/external/expat 338353 338354 338355 338356
# repopick 338357 342116  
repopick 338357 # 342116 was an empty commit and was abandoned with all the others
echo "--- 2022-10 ASB ---"
# For the 2022-10 ASB some picks need manual path spec
# repopick -t P_asb_2022-10    # Fails because of path noth found in 342096
repopick 342095
repopick --path /home/puma/android/lineage/external/dtc 342096
# repopick 342097 342098 342099 342100 342119
repopick 342097 342098 342099 342100 # 342119 was empty commit and abandoned with all the others 
echo "--- 2022-11 ASB ---"
# For the 2022-11 ASB some picks need manual path spec
# repopick -t P_asb_2022-11   # Fails because of path not found in 344161
# 344167 'RESTRICT AUTOMERGE - [Fix vulnerability] setSecurityLevel in clearkey'
# does not build on Pro1: "unknown type 'DeviceFiles'" in DrmPlugin.h
repopick --path /home/puma/android/lineage/external/dtc 344161
repopick -e 344161,344167 -t P_asb_2022-11
echo "--- 2022-12 ASB ---"
# repopick -t P_asb_2022-12 ASB fails because of path not found in 345891
repopick --path /home/puma/android/lineage/external/dtc 345891
repopick -e 345891 -t P_asb_2022-12
echo "--- 2023-01 ASB ---"
# repopick -t P_asb_2023-01 seems to just work
repopick -t P_asb_2023-01
echo "--- 2023-02 ASB ---"
# repopick -t P_asb_2023-02 fails 'cause of path not found in 349328
repopick --path /home/puma/android/lineage/external/expat 349328
repopick -e 349328 -t P_asb_2023-02
echo "--- 2023-03 ASB ---"
repopick -t P_asb_2023-03  # verified but not merged
echo "--- 2023-04 ASB ---"
repopick -t P_asb_2023-04  # verified but not merged
echo "--- 2023-05 ASB ---"
repopick -t P_asb_2023-05  # unverified as of 20230516
echo "--- 2023-06 ASB ---"
repopick -t P_asb_2023-06  # verified but not merged
echo "--- 2023-07 ASB ---"
# path not found automatically for two patches
repopick -e 361280,361281 -t P_asb_2023-07 # verified but not merged 
repopick --path /home/puma/android/lineage/tools/apksig 361280
repopick --path /home/puma/android/lineage/tools/apksig 361281
echo "--- 2023-08 ASB ---"
repopick -e 365328 -t P_asb_2023-08 # verified by not merged
repopick --path /home/puma/android/lineage/system/ca-certificates 365328
echo "--- 2023-09 ASB ---"
repopick -t P_asb_2023-09
echo "--- 2023-10 ASB ---"
repopick -e 370701 -t P_asb_2023-10
repopick --path /home/puma/android/lineage/external/libxml2 370701
echo "--- 2023-11 ASB ---"
repopick -e 374916 -t P_asb_2023-11
repopick --path /home/puma/android/lineage/system/ca-certificates 374916
echo "--- 2023-12 ASB ---"
repopick -t P_asb_2023-12
echo "--- 2024-01 ASB ---"
repopick -t P_asb_2024-01
echo "--- 2024-02 ASB ---"
repopick -t P_asb_2024-02
echo "--- 2024-03 ASB ---"
repopick -t P_asb_2024-03
#
#
cd $thisdir
#
# Next, include our own patches, watch for errors here that may occur if any 
# file was touched upstream
#
patch -N -d / -p0 -r - --verbose < patches/enable_agps.patch
patch -N -d / -p0 -r - --verbose < patches/enable_high_keycodes.patch
patch -N -d / -p0 -r - --verbose < patches/slion_s_fn-tab_driver.patch
patch -N -d / -p0 -r - --verbose < patches/prevent_duplicate_keystrokes.patch 
patch -N -d / -p0 -r - --verbose < patches/increase_debounce-interval_idea-keys.patch 
patch -N -d / -p0 -r - --verbose < patches/adjust_powerhint_QoS.patch
patch -N -d / -p0 -r - --verbose < patches/keyboard_panel.patch
patch -N -d / -p0 -r - --verbose < patches/cpu_runtime_variant.patch    
patch -N -d / -p0 -r - --verbose < patches/surfaceflinger_opti.patch
patch -N -d / -p0 -r - --verbose < patches/silence_keyboard_driver.patch
patch -N -d / -p0 -r - --verbose < patches/bump_security_string.patch
patch -N -d / -p0 -r - --verbose < patches/enable_dualshock_support.patch
patch -N -d / -p0 -r - --verbose < patches/disable_lock_of_modifier_keys.patch

